/////////////////////////////////////////////////////////////////////////
//
// © University of Southampton IT Innovation Centre, 2017
//
// Copyright in this software belongs to University of Southampton
// IT Innovation Centre of Gamma House, Enterprise Road, 
// Chilworth Science Park, Southampton, SO16 7NS, UK.
//
// This software may not be used, sold, licensed, transferred, copied
// or reproduced in whole or in part in any manner or form or in or
// on any media by any person other than in accordance with the terms
// of the Licence Agreement supplied with the software, or otherwise
// without the prior written consent of the copyright owners.
//
// This software is distributed WITHOUT ANY WARRANTY, without even the
// implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
// PURPOSE, except where stated in the Licence Agreement supplied with
// the software.
//
//      Created By :            Simon Crowle
//      Created Date :          19/12/2017
//      Created for Project :   FLAME
//
/////////////////////////////////////////////////////////////////////////
package uk.ac.soton.innovation.flame.clmc.monspec.test.base;

import java.util.Properties;
import org.influxdb.InfluxDB;
import org.junit.After;
import org.junit.AfterClass;
import org.junit.Before;
import org.junit.BeforeClass;
import org.junit.runner.RunWith;
import org.junit.runners.Suite;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;


@RunWith(Suite.class)
@Suite.SuiteClasses({})
/**
 * TestSuiteBase is an abstract class used to set up Influx test suites. Derive 
 * from this class to create InfluxDB test suites
 */
public abstract class TestSuiteBase
{
    private static Logger logger = LoggerFactory.getLogger( TestSuiteBase.class );
    
    @BeforeClass
    public static void setUpClass() throws Exception 
    {
        InfluxUtility.getInfluxDBConnection(); // throws if connection fails
        
        destroyTestDatabase();
    }

    @AfterClass
    public static void tearDownClass() throws Exception
    {
        Properties config = InfluxUtility.getTestConfig();
        
        if ( "true".equals( config.getProperty("clearDBOnExit")) )
            destroyTestDatabase();
    }

    @Before
    public void setUp() throws Exception
    {
        
    }

    @After
    public void tearDown() throws Exception
    {
        
    }
    
    // Private methods ---------------------------------------------------------
    private static void destroyTestDatabase()
    {
        try
        {
            String dbName = InfluxUtility.getTestConfig().getProperty( "influxDB_DB" );
            InfluxDB influxDB = InfluxUtility.getInfluxDBConnection();
            
            if ( influxDB.databaseExists( dbName ) )
                influxDB.deleteDatabase( dbName );
        }
        catch ( Exception ex )
        {
            logger.error( ex.getMessage() );
        }
    }
}
